@@ -120,7 +120,6 @@ Accounting stuff
     tim2lino
     sepa
     invoicing
-    vat
     vatless
     bevat
     bevats
@@ -128,6 +127,9 @@ Accounting stuff
     ana
     sheets
 
+The following plugins are already migrated to full narrative docs
+:mod:`lino_xl.lib.vat`
+
 Plugin namespaces
 =======================
 
