@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2021 Rumma & Ko Ltd
+# Copyright 2009-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import datetime
@@ -227,7 +227,7 @@ class Entries(dd.Table):
 
     hide_top_toolbar = False
 
-    display_mode = 'list'
+    display_mode_main = 'list'
     disabled_display_mode = None # Something to play with (TODO)
 
     insert_layout = """
@@ -254,7 +254,7 @@ class PublicEntries(Entries):
     comments.CommentsByRFC
     """
 
-    display_mode = constants.DISPLAY_MODE_STORY
+    display_mode_main = constants.DISPLAY_MODE_STORY
 
     item_layout = "item_preview"
 
@@ -294,7 +294,7 @@ class EntriesByController(Entries):
     master_key = 'owner'
     column_names = "pub_date title user *"
     order_by = ["-pub_date"]
-    display_mode = "summary"
+    display_mode_main = "summary"
 
     @classmethod
     def get_table_summary(self, mi, ar):
