@@ -18,14 +18,24 @@ from lino.utils.format_date import fds
 
 from .utils import day_and_month
 
+class DisplayColor(dd.Choice):
+    font_color = None
+
 class DisplayColors(dd.ChoiceList):
     verbose_name = _("Display color")
     verbose_name_plural = _("Display colors")
     required_roles = dd.login_required(dd.SiteStaff)
+    item_class = DisplayColor
+
 add = DisplayColors.add_item
-cssColos = 'White Silver Gray Black Red Maroon Yellow Olive Lime Green Aqua Teal Blue Navy Fuchsia Purple'
-for color in cssColos.split():
-    add(color, _(color),color)
+cssColors = 'White Silver Gray Black Red Maroon Yellow Olive Lime Green Aqua Teal Blue Navy Fuchsia Purple'
+for color in cssColors.split():
+    add(color, _(color), color, font_color="white")
+
+lightColors = 'White Silver Gray'
+for color in lightColors.split():
+    DisplayColors.get_by_value(color).font_color = "black"
+
 
 class Weekdays(dd.ChoiceList):
     verbose_name = _("Weekday")
@@ -271,3 +281,13 @@ if False:
     add('75', _("Omitted"), 'omitted', fixed=True, transparent=True,
         button_text="☒")  # BALLOT BOX WITH X (\u2612)
         # button_text="☹")  # 2639
+
+
+class NotifyBeforeUnits(dd.ChoiceList):
+    verbose_name = _("Unit")
+    verbose_name_plural = _("Notify Units")
+add = NotifyBeforeUnits.add_item
+add('10', _('minutes'), 'minutes')
+add('20', _('hours'), 'hours')
+add('30', _('days'), 'days')
+add('40', _('weeks'), 'weeks')
