@@ -323,13 +323,15 @@ class EventPolicy(mixins.BabelNamed, RecurrenceSet):
 
 
 # class AutomaticSeries(RecurrenceSet, EventGenerator):
-class EventRepeater(Controllable, RecurrenceSet, EventGenerator):
+class EntryRepeater(RecurrenceSet, EventGenerator):
 
     class Meta:
         app_label = 'cal'
-        verbose_name = _("Event repeater")
-        verbose_name_plural = _("Event repeaters")
-        abstract = dd.is_abstract_model(__name__, 'EventRepeater')
+        verbose_name = _("Cal entry repeater")
+        verbose_name_plural = _("Cal entry repeaters")
+        abstract = dd.is_abstract_model(__name__, 'EntryRepeater')
+
+    cal_entry = dd.ForeignKey('cal.Event', related_name='repeaters')
 
     def change_event_attribute(self, attr, value):
         pass
@@ -438,8 +440,6 @@ class Event(
     notify_unit = NotifyBeforeUnits.field(default='minutes')
     notified = models.BooleanField(default=False)
 
-    repeater = models.ForeignKey('cal.EventRepeater', on_delete=models.SET_NULL, null=True, blank=True)
-
     move_next = MoveEntryNext()
 
     show_conflicting = dd.ShowSlaveTable(ConflictingEvents)
@@ -784,11 +784,6 @@ class Event(
         super(Event, self).before_ui_save(ar, cw)
 
     def on_create(self, ar):
-        if self.repeater is None:
-            repeater = rt.models.cal.EventRepeater()
-            repeater.full_clean()
-            repeater.save()
-            self.repeater = repeater
         if self.event_type is None:
             # print("20200513", ar.user)
             self.event_type = ar.get_user().event_type or \
@@ -1249,7 +1244,7 @@ class Guest(Printable):   # TODO: rename the model to "Presence"
         # m = dd.plugins.cal.partner_model
         # return m.objects.order_by(*m.get_default_table().order_by)
 
-    def create_partner_choice(self, text):
+    def create_partner_choice(self, text, ar=None):
         return dd.plugins.cal.partner_model.create_from_choice(text)
 
     def delete(self, **kw):
