@@ -28,13 +28,13 @@ class ContactRelated(dd.Model):
         "contacts.Person",
         related_name="%(app_label)s_%(class)s_set_by_contact_person",
         blank=True, null=True,
-        verbose_name=_("represented by"))
+        verbose_name=_("Represented by"))
 
     contact_role = dd.ForeignKey(
         "contacts.RoleType",
         related_name="%(app_label)s_%(class)s_set_by_contact_role",
         blank=True, null=True,
-        verbose_name=_("represented as"))
+        verbose_name=_("Represented as"))
 
     @dd.chooser()
     def contact_person_choices(cls, company):
