@@ -41,7 +41,7 @@ class CountryCity(dd.Model):
     def country_choices(cls):
         return rt.models.countries.Country.get_actual_countries()
 
-    def create_city_choice(self, text):
+    def create_city_choice(self, text, ar=None):
         """
         Called when an unknown city name was given.
 
@@ -127,9 +127,9 @@ class CountryRegionCity(CountryCity):
             flt = models.Q(type__lt=PlaceTypes.get_by_value('50'))
             return Place.objects.filter(flt).order_by('name')
 
-    def create_city_choice(self, text):
+    def create_city_choice(self, text, ar=None):
         # if a Place is created by super, then we add our region
-        obj = super(CountryRegionCity, self).create_city_choice(text)
+        obj = super(CountryRegionCity, self).create_city_choice(text, ar)
         obj.region = self.region
         return obj
 
