@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2021 Rumma & Ko Ltd
+# Copyright 2008-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.db import models
@@ -89,7 +89,7 @@ class LanguageKnowledgesByPerson(LanguageKnowledges):
     column_names = "language native spoken written cef_level has_certificate entry_date *"
     required_roles = dd.login_required(CareerUser)
     auto_fit_column_widths = True
-    display_mode = "summary"
+    display_mode_main = "summary"
     window_size  = (70, 15)
     detail_layout = dd.DetailLayout("""
     language
