@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2014-2019 Rumma & Ko Ltd
+# Copyright 2014-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import logging ; logger = logging.getLogger(__name__)
@@ -709,7 +709,7 @@ class ExcerptsByOwner(Excerpts):
     label = _("Existing excerpts")
     column_names = "build_time excerpt_type user project *"
     order_by = ['-build_time', 'id']
-    display_mode = 'summary'
+    display_mode_main = 'summary'
     auto_fit_column_widths = True
     MORE_LIMIT = 5
 
