@@ -68,5 +68,5 @@ class Plugin(ad.Plugin):
         m.add_action('extensible.CalendarPanel')
 
 
-    def get_quicklinks(site, user):
+    def get_quicklinks(site):
         yield 'extensible.CalendarPanel'
