@@ -44,13 +44,14 @@ class Plugin(ad.Plugin):
     application_name = "LinoOAuthClient"
     """ The Application's name defined in the google API Console"""
 
-    @classmethod
-    def setup_site_features(self, feats):
-        feats.activate('third_party_authentication', priority=1000)
+    # @classmethod
+    # def setup_site_features(self, feats):
+    #     site.define_feature('third_party_authentication')
+        # feats.activate('third_party_authentication', priority=1000)
 
     def on_init(self):
         super().on_init()
-        if not self.has_feature('third_party_authentication'):
+        if not self.site.has_feature('third_party_authentication'):
             return
         from lino.core.site import has_socialauth
         if has_socialauth:
