@@ -46,14 +46,14 @@ class InvoicingInfo(object):
     # tariff = None
     # 20210724
     invoiceable_product = None
-    # invoiceable_qty = None
+    invoiceable_qty = None
     asset_to_buy = None
     number_of_events = None
     min_asset = None
     max_asset = None
 
     def __init__(self, enr, min_date, max_date):
-        # print("20210731 InvoicingInfo()", enr)
+        # print("20220507 InvoicingInfo()", enr)
         self.generator = enr
         self.min_date = min_date
         self.max_date = max_date
@@ -73,6 +73,7 @@ class InvoicingInfo(object):
         if product is not None:
             qs = qs.filter(product=product)
         self.invoicings = qs
+        self.invoiceable_qty = enr.get_invoiceable_qty()
 
         sub = enr.get_invoicing_periodicity(product)
         if sub is not None:
@@ -115,13 +116,13 @@ class InvoicingInfo(object):
                 self.invoiced_qty += obj.qty
                 if self.number_of_events:
                     self.invoiced_events += int(obj.qty * self.number_of_events)
-        # print("20160414", self.invoicings, self.invoiced_qty)
+        # print("20220507 invoiced, invoiceable qty", self.invoiced_qty, self.invoiceable_qty)
 
         # print("20181116 f %s", self.tariff.number_of_events)
         if self.number_of_events:
             asset = self.invoiced_events - len(self.used_events)
             # dd.logger.info(
-            #     "20181119 %s %s %s %s",
+            #     "20220507 %s %s %s %s",
             #     start_date, max_date, asset, self.min_asset)
             if end_date and end_date < max_date and asset >= 0:
                 # ticket #1040 : a participant who declared to stop before
@@ -139,10 +140,19 @@ class InvoicingInfo(object):
             if self.max_asset is not None:
                 self.asset_to_buy = min(self.asset_to_buy, self.max_asset)
 
-        elif self.invoiced_qty <= 0:
-            self.asset_to_buy = 1
-        else:
+        # removed 20220507 because i don't see why it was:
+        # elif self.invoiced_qty <= 0:
+        #     self.asset_to_buy = 1
+        elif self.invoiceable_qty in (None, ''):
             return
+        else:
+            self.invoiceable_qty -= self.invoiced_qty
+            if self.invoiceable_qty <= 0:
+                return
+            # self.asset_to_buy = self.invoiceable_qty - self.invoiced_qty
+            # # print("20220507 self.asset_to_buy", self.asset_to_buy)
+            # if self.asset_to_buy <= 0:
+            #     return
 
         # qty = self.asset_to_buy * enr.get_invoiceable_qty()
 
@@ -219,10 +229,11 @@ class InvoiceGenerator(dd.Model):
     class Meta:
         abstract = True
 
-    invoicings = GenericRelation(
-        dd.plugins.invoicing.item_model,
-        content_type_field='invoiceable_type',
-        object_id_field='invoiceable_id')
+    if dd.is_installed("invoicing"):
+        invoicings = GenericRelation(
+            dd.plugins.invoicing.item_model,
+            content_type_field='invoiceable_type',
+            object_id_field='invoiceable_id')
 
     # @classmethod
     # def on_analyze(cls, site):
@@ -256,13 +267,15 @@ class InvoiceGenerator(dd.Model):
 
     def get_invoice_items(self, info, invoice, ar):
 
-        # print("20210727 get_invoice_items()", self, info.invoiceable_product, info.number_of_events)
+        # print("20220507 get_invoice_items()", self,
+        #     info.invoiceable_product, info.invoiceable_qty,
+        #     info.number_of_events)
         # 20210724
         if info.invoiceable_product is None:
             return
 
-        invoiceable_qty = self.get_invoiceable_qty()
-        if invoiceable_qty is None:
+        # invoiceable_qty = self.get_invoiceable_qty()
+        if info.invoiceable_qty is None:
             return
 
         # 20210724
@@ -270,12 +283,9 @@ class InvoiceGenerator(dd.Model):
         # 20210804 kwargs = dict(invoiceable=self, product=info.invoiceable_product)
         # kwargs = dict(invoiceable=self)
 
-        asset_to_buy = info.asset_to_buy
-        if asset_to_buy is None:
-            return
-
         if info.number_of_events is None:
-            qty = asset_to_buy * invoiceable_qty
+            # qty = asset_to_buy * info.invoiceable_qty
+            qty = info.invoiceable_qty
             kwargs.update(
                 title=self.get_invoiceable_title(), qty=qty)
             i = invoice.add_voucher_item(**kwargs)
@@ -283,13 +293,17 @@ class InvoiceGenerator(dd.Model):
             yield i
             return
 
+        asset_to_buy = info.asset_to_buy
+        if asset_to_buy is None:
+            return
+
         # sell the asset in chunks
 
         number = info.invoiced_events // info.number_of_events
         while asset_to_buy > 0:
             number += 1
             kwargs.update(
-                title=self.get_invoiceable_title(number), qty=invoiceable_qty)
+                title=self.get_invoiceable_title(number), qty=info.invoiceable_qty)
             i = invoice.add_voucher_item(**kwargs)
             i.discount_changed(ar)
             yield i
@@ -326,6 +340,7 @@ class InvoiceGenerator(dd.Model):
         return
 
     def get_invoiceable_end_date(self):
+        # todo: return None here (but have existing children return self.end_date)
         return self.end_date
 
     def get_invoiceable_start_date(self, max_date):
