@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2020 Rumma & Ko Ltd
+# Copyright 2008-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.conf import settings
@@ -14,6 +14,7 @@ from lino.mixins.registrable import RegistrableState
 # from lino_xl.lib.ledger.utils import DC
 from .roles import LedgerStaff
 
+has_payment_methods = dd.get_plugin_setting('ledger', 'has_payment_methods', False)
 
 
 class Debit(dd.Choice):
@@ -185,6 +186,9 @@ add('4900', _("Waiting account"), 'waiting', True)
 
 add('5500', _("BestBank"), 'best_bank', False)
 add('5700', _("Cash"), 'cash', False)
+if has_payment_methods:
+    add('5701', _("Online payments"), 'online_payments', False)
+    add('5702', _("Credit card payments"), 'credit_card_payments', False)
 
 add('6040', _("Purchase of goods"), 'purchase_of_goods', False)
 add('6010', _("Purchase of services"), 'purchase_of_services', False)
@@ -208,7 +212,7 @@ class VoucherType(dd.Choice):
         if text is None:
             # text = model._meta.verbose_name + ' (%s)' % dd.full_model_name(model)
             # text = model._meta.verbose_name + ' (%s.%s)' % (
-            text = format_lazy(u"{} ({})",model._meta.verbose_name, value)
+            text = format_lazy("{} ({})", model._meta.verbose_name, value)
         #     model.__module__, model.__name__)
         name = None
         super(VoucherType, self).__init__(value, text, name)
