@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2021 Rumma & Ko Ltd
+# Copyright 2008-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.db import models
@@ -18,6 +18,9 @@ from .utils import Balance
 from .utils import DC, ZERO
 
 
+has_payment_methods = dd.get_plugin_setting('ledger', 'has_payment_methods', False)
+
+
 class Accounts(dd.Table):
     model = 'ledger.Account'
     required_roles = dd.login_required(LedgerStaff)
@@ -204,10 +207,12 @@ class PaymentTerms(dd.Table):
     printed_text
     """
 
+if has_payment_methods:
 
-class PaymentMethods(dd.Table):
-    required_roles = dd.login_required(LedgerStaff)
-    model = "ledger.PaymentMethod"
+    class PaymentMethods(dd.Table):
+        required_roles = dd.login_required(LedgerStaff)
+        model = "ledger.PaymentMethod"
+        column_names = "id designation payment_account is_cash *"
 
 
 class Vouchers(dd.Table):
