@@ -15,6 +15,7 @@ from lino.utils import join_elems
 from lino.core.fields import TableRow
 from lino.mixins import Referrable
 from lino.modlib.users.mixins import My, UserAuthored
+from lino.modlib.memo.mixins import truncate_comment
 
 from .utils import ResponseStates, PollStates
 from .roles import PollsUser, PollsStaff
@@ -294,7 +295,7 @@ class ToggleChoice(dd.Action):
         else:
             raise Exception(
                 "Oops, %s returned %d rows." % (qs.query, qs.count()))
-        ar.success(refresh=True)
+        ar.success(refresh=True, refresh_delayed_value=True)
         # dd.logger.info("20140930 %s", obj)
 
 
@@ -456,6 +457,11 @@ class AnswerRemark(dd.Model):
     question = dd.ForeignKey('polls.Question')
     remark = models.TextField(_("My remark"), blank=True)
 
+    def full_clean(self, *args, **kwargs):
+        if self.remark:
+            self.remark = truncate_comment(self.remark, max_p_len=-1)
+        super().full_clean(*args, **kwargs)
+
     def __str__(self):
         # return _("Remark for {0}").format(self.question)
         return str(self.question)
