@@ -1,10 +1,7 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2014-2018 Rumma & Ko Ltd
+# Copyright 2014-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-
-from __future__ import unicode_literals
-
 from django.db import models
 from lino.api import dd, _, rt
 from lino.core.diff import ChangeWatcher
@@ -46,7 +43,7 @@ class Account(dd.Model):
     allow_cascaded_delete = ['partner']
 
     def __str__(self):
-        return IBAN_FORMFIELD.prepare_value(self.iban)
+        return IBAN_FORMFIELD.prepare_value(self.iban) or ""
         # if self.remark:
         #     return "{0} ({1})".format(self.iban, self.remark)
         # return self.iban
@@ -112,6 +109,3 @@ dd.inject_field(
     'ledger.Journal',
     'sepa_account',
     dd.ForeignKey('sepa.Account', blank=True, null=True))
-
-
-    
