@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2020 Rumma & Ko Ltd
+# Copyright 2011-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
@@ -21,6 +21,7 @@ from lino.modlib.notify.choicelists import MessageTypes
 from lino.modlib.memo.mixins import rich_text_to_elems
 from lino.modlib.uploads.mixins import UploadController
 from lino.modlib.users.mixins import UserAuthored
+from lino.modlib.checkdata.choicelists import Checker
 
 from lino_xl.lib.contacts.mixins import ContactRelated
 from lino_xl.lib.skills.mixins import Feasible
@@ -872,6 +873,26 @@ class Link(dd.Model):
             type=self.type.as_child())
 
 
+class LinkChecker(Checker):
+
+    verbose_name = _("Find dependencies that will get lost")
+    model = 'tickets.Link'
+
+    def get_checkdata_problems(self, obj, fix=False):
+        if obj.child is None or obj.parent is None:
+            return
+        if obj.child.parent != obj.parent:
+            yield (True, _("{} but parent is {}").format(obj, obj.child.parent))
+            if fix:
+                obj.child.parent = obj.parent
+                obj.child.full_clean()
+                obj.child.save()
+
+
+LinkChecker.activate()
+
+
+
 # dd.inject_field(
 #     'users.User', 'project',
 #     dd.ForeignKey(
