@@ -162,7 +162,7 @@ class LinksByTicket(Links):
     required_roles = dd.login_required(Triager)
     master = 'tickets.Ticket'
     column_names = 'parent type_as_parent:10 child'
-    display_mode = 'summary'
+    display_mode_main = 'summary'
 
     @classmethod
     def get_request_queryset(self, ar):
@@ -532,7 +532,7 @@ class AllTickets(Tickets):
 
 
 class DuplicatesByTicket(Tickets):
-    display_mode = 'html'
+    display_mode_main = 'html'
     label = _("Duplicates")
     master_key = 'duplicate_of'
     column_names = "overview state *"
@@ -580,7 +580,7 @@ class UnassignedTickets(Tickets):
 class TicketsByEndUser(Tickets):
     master_key = 'end_user'
     column_names = ("overview:50 workflow_buttons * ")
-    # display_mode = "summary"
+    # display_mode_main = "summary"
     required_roles = dd.login_required(TicketsReader)
 
     @classmethod
@@ -740,7 +740,7 @@ class MyTickets(My, Tickets):
 # class TicketsSummary(Tickets):
 #     # order_by = ["state", "priority", "-id"]
 #     order_by = ["priority", "-id"]
-#     display_mode = 'summary'
+#     display_mode_main = 'summary'
 #
 #     @classmethod
 #     def get_table_summary(self, master, ar):
