@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2021 Rumma & Ko Ltd
+# Copyright 2012-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import time
@@ -10,6 +10,7 @@ from etgen.html import E, forcetext
 from django.db import models
 from lino_xl.lib.ledger.roles import LedgerStaff
 from lino_xl.lib.ledger.choicelists import DC, TradeTypes, CommonAccounts
+from lino.modlib.checkdata.choicelists import Checker
 
 from lino_xl.lib.ledger.utils import ZERO
 
@@ -26,7 +27,6 @@ if dd.is_installed('vat'):
 
     random.seed(1)
 
-    from lino.modlib.checkdata.choicelists import Checker
 
 
 class VatClasses(dd.ChoiceList):
@@ -746,16 +746,17 @@ if dd.is_installed('vat'):
                         elif result.is_valid is None:
                             return
                         else:
+                            # dd.logger.info("Verified online: %s", self.value)
                             # TODO: compare the name
                             return
                     except pyvat.exceptions.ServerError as e:
-                        dd.logger.info(
-                            "pyvat.check_vat_number('%s', '%s') failed with {}:",
-                            self.vn, self.country_code, e)
                         if result is None:
-                            dd.logger.info("   (no response)")
+                            msg = "(no response)"
                         else:
-                            dd.logger.info("  " + ("\n  ".join(result.log_lines)))
+                            msg = ":\n  " + ("\n  ".join(result.log_lines))
+                        dd.logger.info(
+                            "pyvat.check_vat_number('%s', '%s') failed with %s: %s",
+                            self.vn, self.country_code, e, msg)
                         if attempts > MAX_ONLINE_ATTEMPTS:
                             raise ValidationError(str(e))
                         time.sleep(1)
@@ -917,8 +918,7 @@ class VatSubjectable(dd.Model):
                 self.vat_id_changed()
             return self._vnm
 
-
-if dd.is_installed('vat') and dd.plugins.vat.use_online_check:
+if dd.is_installed('vat'):
 
     class VatIdChecker(Checker):
         model = VatSubjectable
@@ -926,7 +926,7 @@ if dd.is_installed('vat') and dd.plugins.vat.use_online_check:
 
         def get_checkdata_problems(self, obj, fix=False):
             try:
-                obj.vid_manager.validate(online=True)
+                obj.vid_manager.validate(online=dd.plugins.vat.use_online_check)
             except ValidationError as e:
                 yield (False, e.message)
 
