@@ -77,7 +77,7 @@ class ItemsByInvoice(ItemsByVoucher):
 
 
 class VouchersByPartner(VouchersByPartnerBase):
-    label = _("VAT vouchers")
+    label = _("Trade vouchers")
     column_names = "entry_date voucher total_incl total_base total_vat"
     _voucher_base = VatDocument
 
