@@ -1,19 +1,16 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2016 Rumma & Ko Ltd
-#
+# Copyright 2016-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
-"""No longer used. We chose to manually create demo votes in
+"""We also to manually create demo votes in
 :mod:`lino_noi.projects.care.lib.tickets.fixtures.demo`
 
 """
 
-from __future__ import unicode_literals
-
 from lino.utils.cycler import Cycler
 from lino.api import dd, rt
 
 
-def unused_objects():
+def objects():
 
     Vote = rt.models.votes.Vote
     VoteStates = rt.models.votes.VoteStates
@@ -27,5 +24,7 @@ def unused_objects():
             USERS.pop()  # not every user votes
             obj = Vote(
                 state=STATES.pop(), user=USERS.pop(), votable=TICKETS.pop())
-            if obj.user != obj.votable.user:
-                yield obj
+            yield obj
+            # 20210907
+            # if obj.user != obj.votable.user:
+            #     yield obj
